==> Net-RDAP-0.3.tar.gz: Net-RDAP-0.3/lib/Net/RDAP/Link.pm <==
package Net::RDAP::Link;
use URI;
use MIME::Type;
use strict;

=pod

=head1 NAME

L<Net::RDAP::Link> - a module representing an RDAP link.

=head1 DESCRIPTION

Links are used throughout RDAP; the following objects may contain zero
or more links:

=over

=item * top-level responses (see L<Net::RDAP::Response>)

=item * remarks (see L<Net::RDAP::Remark>)

=item * notices (see L<Net::RDAP::Notice>)

=item * events (see L<Net::RDAP::Event>)

=back

In most cases, the modules representing these types of object provide a
C<links()> method which will return a (potentially empty) array of
L<Net::RDAP::Link> objects.

The available methods are:

=cut

sub new {
	my ($package, $args) = @_;
	my %self = %{$args};
	return bless(\%self, $package);
}

=pod

	$value = $link->value;

Returns the "value" of the link. This corresponds to the text
content of the C<E<lt>aE<gt>> element if the link if it were
represented in HTML.

=cut

sub value { $_[0]->{'value'} }

=pod

	$rel = $link->rel;

Returns the "relationship" attribute. The possible values are defined by
an IANA registry; see:

=over

=item * L<https://www.iana.org/assignments/link-relations/link-relations.xhtml>

=back

=cut

sub rel { $_[0]->{'rel'} }

=pod

	$url = $link->href;

Returns a L<URI> object corresponding to the target of the link.

=cut

sub href { URI->new($_[0]->{'href'}) }

=pod

	@languages = $link->hreflang;

Returns a (potentially empty) array containing the ISO-639-2 codes
which describe the language that the target is available in.

=cut

sub hreflang { $_[0]->{'hreflang'} ? @{$_[0]->{'hreflang'}} : undef }

=pod

	$title = $link->title;

Returns the "title" attribute of the link. This corresponds to the
mousover tooltip content of the C<E<lt>aE<gt>> element if the link if
it were represented in HTML.

=cut

sub title { $_[0]->{'title'} }

=pod

	$media = $link->media;

Returns the "media" attribute of the link. This corresponds to the
media/device the target resource is optimized for.

=cut

sub media { $_[0]->{'media'} }

=pod

	$type = $link->type;

Returns a L<MIME::Type> object corresponding to the media type of the
target resource.

=cut

sub type { $_[0]->{'type'} ? MIME::Type->new($_[0]->{'type'}) : undef }

=pod

=head1 COPYRIGHT

Copyright 2018 CentralNic Ltd. All rights reserved.

=head1 LICENSE

Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of the author not be used
in advertising or publicity pertaining to distribution of the software
without specific prior written permission.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

=cut

1;

==> Net-RDAP-0.4.tar.gz: Net-RDAP-0.4/lib/Net/RDAP/Link.pm <==
package Net::RDAP::Link;
use URI;
use MIME::Type;
use strict;

=pod

=head1 NAME

L<Net::RDAP::Link> - a module representing an RDAP link.

=head1 DESCRIPTION

Links are used throughout RDAP; the following objects may contain zero
or more links:

=over

=item * objects (see L<Net::RDAP::Object>)

=item * remarks (see L<Net::RDAP::Remark>)

=item * notices (see L<Net::RDAP::Notice>)

=item * events (see L<Net::RDAP::Event>)

=back

In all cases, the modules representing these types of object inherit
from L<Net::RDAP::Base> and therefore provide a C<links()> method
which will return a (potentially empty) array of L<Net::RDAP::Link>
objects.

The available methods are:

=cut

sub new {
	my ($package, $args) = @_;
	my %self = %{$args};
	return bless(\%self, $package);
}

=pod

	$value = $link->value;

Returns the "value" of the link. This corresponds to the text
content of the C<E<lt>aE<gt>> element if the link if it were
represented in HTML.

=cut

sub value { $_[0]->{'value'} }

=pod

	$rel = $link->rel;

Returns the "relationship" attribute. The possible values are defined by
an IANA registry; see:

=over

=item * L<https://www.iana.org/assignments/link-relations/link-relations.xhtml>

=back

=cut

sub rel { $_[0]->{'rel'} }

=pod

	$url = $link->href;

Returns a L<URI> object corresponding to the target of the link.

=cut

sub href { URI->new($_[0]->{'href'}) }

=pod

	@languages = $link->hreflang;

Returns a (potentially empty) array containing the ISO-639-2 codes
which describe the language that the target is available in.

=cut

sub hreflang { $_[0]->{'hreflang'} ? @{$_[0]->{'hreflang'}} : undef }

=pod

	$title = $link->title;

Returns the "title" attribute of the link. This corresponds to the
mousover tooltip content of the C<E<lt>aE<gt>> element if the link if
it were represented in HTML.

=cut

sub title { $_[0]->{'title'} }

=pod

	$media = $link->media;

Returns the "media" attribute of the link. This corresponds to the
media/device the target resource is optimized for.

=cut

sub media { $_[0]->{'media'} }

=pod

	$type = $link->type;

Returns a L<MIME::Type> object corresponding to the media type of the
target resource.

=cut

sub type { $_[0]->{'type'} ? MIME::Type->new($_[0]->{'type'}) : undef }

=pod

=head1 COPYRIGHT

Copyright 2018 CentralNic Ltd. All rights reserved.

=head1 LICENSE

Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of the author not be used
in advertising or publicity pertaining to distribution of the software
without specific prior written permission.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

=cut

1;
